@@ -8,7 +8,7 @@ use crate::http::config::{DispatcherConfig, ServiceConfig};
 use crate::http::error::{DispatchError, ResponseError};
 use crate::http::request::Request;
 use crate::http::response::Response;
-use crate::io::{types, Filter, Io, IoRef};
+use crate::io::{types, Filter, Io, IoRef, TokioIoBoxed};
 use crate::service::{IntoServiceFactory, Service, ServiceFactory};
 use crate::time::Millis;
 use crate::util::Bytes;
@@ -62,7 +62,7 @@ mod openssl {
         S: ServiceFactory<Request> + 'static,
         S::Error: ResponseError,
         S::Response: Into<Response<B>>,
-        B: MessageBody + 'static,
+        B: MessageBody,
     {
         /// Create ssl based service
         pub fn openssl(
@@ -99,7 +99,7 @@ mod rustls {
         S: ServiceFactory<Request> + 'static,
         S::Error: ResponseError,
         S::Response: Into<Response<B>>,
-        B: MessageBody + 'static,
+        B: MessageBody,
     {
         /// Create openssl based service
         pub fn rustls(
@@ -131,7 +131,7 @@ where
     S: ServiceFactory<Request> + 'static,
     S::Error: ResponseError,
     S::Response: Into<Response<B>>,
-    B: MessageBody + 'static,
+    B: MessageBody,
 {
     type Response = ();
     type Error = DispatchError;
@@ -164,15 +164,14 @@ pub struct H2ServiceHandler<F, S: Service<Request>, B> {
 impl<F, S, B> Service<Io<F>> for H2ServiceHandler<F, S, B>
 where
     F: Filter,
-    S: Service<Request>,
-    S::Error: ResponseError + 'static,
-    S::Future: 'static,
-    S::Response: Into<Response<B>> + 'static,
-    B: MessageBody + 'static,
+    S: Service<Request> + 'static,
+    S::Error: ResponseError,
+    S::Response: Into<Response<B>>,
+    B: MessageBody,
 {
     type Response = ();
     type Error = DispatchError;
-    type Future = H2ServiceHandlerResponse<F, S, B>;
+    type Future = H2ServiceHandlerResponse<S, B>;
 
     #[inline]
     fn poll_ready(&self, cx: &mut Context<'_>) -> Poll<Result<(), Self::Error>> {
@@ -198,44 +197,39 @@ where
             state: State::Handshake(
                 io.get_ref(),
                 self.config.clone(),
-                server::Builder::new().handshake(io),
+                server::Builder::new().handshake(TokioIoBoxed::from(io)),
             ),
         }
     }
 }
 
-enum State<F, S: Service<Request>, B: MessageBody>
+enum State<S: Service<Request>, B: MessageBody>
 where
-    F: Filter,
-    S::Future: 'static,
+    S: 'static,
 {
-    Incoming(Dispatcher<F, S, B, (), ()>),
+    Incoming(Dispatcher<S, B, (), ()>),
     Handshake(
         IoRef,
         Rc<DispatcherConfig<S, (), ()>>,
-        Handshake<Io<F>, Bytes>,
+        Handshake<TokioIoBoxed, Bytes>,
     ),
 }
 
-pub struct H2ServiceHandlerResponse<F, S, B>
+pub struct H2ServiceHandlerResponse<S, B>
 where
-    F: Filter,
-    S: Service<Request>,
-    S::Error: ResponseError + 'static,
-    S::Future: 'static,
-    S::Response: Into<Response<B>> + 'static,
-    B: MessageBody + 'static,
+    S: Service<Request> + 'static,
+    S::Error: ResponseError,
+    S::Response: Into<Response<B>>,
+    B: MessageBody,
 {
-    state: State<F, S, B>,
+    state: State<S, B>,
 }
 
-impl<F, S, B> Future for H2ServiceHandlerResponse<F, S, B>
+impl<S, B> Future for H2ServiceHandlerResponse<S, B>
 where
-    F: Filter,
-    S: Service<Request>,
-    S::Error: ResponseError + 'static,
-    S::Future: 'static,
-    S::Response: Into<Response<B>> + 'static,
+    S: Service<Request> + 'static,
+    S::Error: ResponseError,
+    S::Response: Into<Response<B>>,
     B: MessageBody,
 {
     type Output = Result<(), DispatchError>;
