@@ -1,11 +1,9 @@
 use std::{fmt, mem, pin::Pin, task::Context, task::Poll};
 
-use bytes::Bytes;
-use futures_core::Stream;
 use h2::RecvStream;
 
-use super::error::PayloadError;
-use super::{h1, h2 as h2d};
+use super::{error::PayloadError, h1, h2 as h2d};
+use crate::util::{Bytes, Stream};
 
 /// Type represent boxed payload
 pub type PayloadStream = Pin<Box<dyn Stream<Item = Result<Bytes, PayloadError>>>>;
@@ -78,10 +76,7 @@ impl Stream for Payload {
     type Item = Result<Bytes, PayloadError>;
 
     #[inline]
-    fn poll_next(
-        self: Pin<&mut Self>,
-        cx: &mut Context<'_>,
-    ) -> Poll<Option<Self::Item>> {
+    fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Self::Item>> {
         match self.get_mut() {
             Payload::None => Poll::Ready(None),
             Payload::H1(ref mut pl) => pl.readany(cx),
