@@ -40,13 +40,10 @@ pub mod web;
 pub mod ws;
 
 pub use self::service::{
-    apply_fn, boxed, fn_factory, fn_factory_with_config, fn_service, into_service,
-    pipeline, pipeline_factory, IntoService, IntoServiceFactory, Service, ServiceFactory,
-    Transform,
+    fn_service, into_service, pipeline, pipeline_factory, IntoService, IntoServiceFactory,
+    Service, ServiceFactory, Transform,
 };
 
-pub use futures_core::stream::Stream;
-pub use futures_sink::Sink;
 pub use ntex_util::channel;
 pub use ntex_util::task;
 
