@@ -1,31 +1,29 @@
-use std::{
-    future::Future, marker::PhantomData, net::SocketAddr, pin::Pin, task::Context,
-    task::Poll, time::Duration,
-};
+use std::convert::TryInto;
+use std::{future::Future, net::SocketAddr, pin::Pin, task::Context, task::Poll};
 
 use log::error;
 
-use crate::rt::spawn;
+use crate::io::Io;
 use crate::service::{Service, ServiceFactory};
-use crate::util::{counter::CounterGuard, Ready};
+use crate::util::{Pool, PoolId, Ready};
+use crate::{rt::spawn, time::Millis};
 
-use super::socket::{FromStream, Stream};
-use super::Token;
+use super::{counter::CounterGuard, socket::Stream, Config, Token};
 
 /// Server message
 pub(super) enum ServerMessage {
     /// New stream
     Connect(Stream),
-    /// Gracefull shutdown
-    Shutdown(Duration),
+    /// Gracefull shutdown in millis
+    Shutdown(Millis),
     /// Force shutdown
     ForceShutdown,
 }
 
-pub trait StreamServiceFactory<Stream: FromStream>: Send + Clone + 'static {
-    type Factory: ServiceFactory<Config = (), Request = Stream>;
+pub(super) trait StreamServiceFactory: Send + Clone + 'static {
+    type Factory: ServiceFactory<Io>;
 
-    fn create(&self) -> Self::Factory;
+    fn create(&self, _: Config) -> Self::Factory;
 }
 
 pub(super) trait InternalServiceFactory: Send {
@@ -40,7 +38,7 @@ pub(super) trait InternalServiceFactory: Send {
 
 pub(super) type BoxedServerService = Box<
     dyn Service<
-        Request = (Option<CounterGuard>, ServerMessage),
+        (Option<CounterGuard>, ServerMessage),
         Response = (),
         Error = (),
         Future = Ready<(), ()>,
@@ -49,29 +47,37 @@ pub(super) type BoxedServerService = Box<
 
 pub(super) struct StreamService<T> {
     service: T,
+    pool: Pool,
 }
 
 impl<T> StreamService<T> {
-    pub(crate) fn new(service: T) -> Self {
-        StreamService { service }
+    pub(crate) fn new(service: T, pid: PoolId) -> Self {
+        StreamService {
+            service,
+            pool: pid.pool(),
+        }
     }
 }
 
-impl<T, I> Service for StreamService<T>
+impl<T> Service<(Option<CounterGuard>, ServerMessage)> for StreamService<T>
 where
-    T: Service<Request = I>,
+    T: Service<Io>,
     T::Future: 'static,
     T::Error: 'static,
-    I: FromStream,
 {
-    type Request = (Option<CounterGuard>, ServerMessage);
     type Response = ();
     type Error = ();
     type Future = Ready<(), ()>;
 
     #[inline]
-    fn poll_ready(&self, ctx: &mut Context<'_>) -> Poll<Result<(), Self::Error>> {
-        self.service.poll_ready(ctx).map_err(|_| ())
+    fn poll_ready(&self, cx: &mut Context<'_>) -> Poll<Result<(), Self::Error>> {
+        let ready = self.service.poll_ready(cx).map_err(|_| ())?.is_ready();
+        let ready = self.pool.poll_ready(cx).is_ready() && ready;
+        if ready {
+            Poll::Ready(Ok(()))
+        } else {
+            Poll::Pending
+        }
     }
 
     #[inline]
@@ -82,11 +88,13 @@ where
     fn call(&self, (guard, req): (Option<CounterGuard>, ServerMessage)) -> Self::Future {
         match req {
             ServerMessage::Connect(stream) => {
-                let stream = FromStream::from_stream(stream).map_err(|e| {
+                let stream = stream.try_into().map_err(|e| {
                     error!("Cannot convert to an async io stream: {}", e);
                 });
 
                 if let Ok(stream) = stream {
+                    let stream: Io<_> = stream;
+                    stream.set_memory_pool(self.pool.pool_ref());
                     let f = self.service.call(stream);
                     spawn(async move {
                         let _ = f.await;
@@ -102,18 +110,16 @@ where
     }
 }
 
-pub(super) struct Factory<F: StreamServiceFactory<Io>, Io: FromStream> {
+pub(super) struct Factory<F: StreamServiceFactory> {
     name: String,
     inner: F,
     token: Token,
     addr: SocketAddr,
-    _t: PhantomData<Io>,
 }
 
-impl<F, Io> Factory<F, Io>
+impl<F> Factory<F>
 where
-    F: StreamServiceFactory<Io>,
-    Io: FromStream + Send + 'static,
+    F: StreamServiceFactory,
 {
     pub(crate) fn create(
         name: String,
@@ -126,15 +132,13 @@ where
             token,
             inner,
             addr,
-            _t: PhantomData,
         })
     }
 }
 
-impl<F, Io> InternalServiceFactory for Factory<F, Io>
+impl<F> InternalServiceFactory for Factory<F>
 where
-    F: StreamServiceFactory<Io>,
-    Io: FromStream + Send + 'static,
+    F: StreamServiceFactory,
 {
     fn name(&self, _: Token) -> &str {
         &self.name
@@ -146,22 +150,21 @@ where
             inner: self.inner.clone(),
             token: self.token,
             addr: self.addr,
-            _t: PhantomData,
         })
     }
 
     fn create(
         &self,
-    ) -> Pin<Box<dyn Future<Output = Result<Vec<(Token, BoxedServerService)>, ()>>>>
-    {
+    ) -> Pin<Box<dyn Future<Output = Result<Vec<(Token, BoxedServerService)>, ()>>>> {
         let token = self.token;
-        let fut = self.inner.create().new_service(());
+        let cfg = Config::default();
+        let fut = self.inner.create(cfg.clone()).new_service(());
 
         Box::pin(async move {
             match fut.await {
                 Ok(inner) => {
                     let service: BoxedServerService =
-                        Box::new(StreamService::new(inner));
+                        Box::new(StreamService::new(inner, cfg.0.pool.get()));
                     Ok(vec![(token, service)])
                 }
                 Err(_) => Err(()),
@@ -181,22 +184,20 @@ impl InternalServiceFactory for Box<dyn InternalServiceFactory> {
 
     fn create(
         &self,
-    ) -> Pin<Box<dyn Future<Output = Result<Vec<(Token, BoxedServerService)>, ()>>>>
-    {
+    ) -> Pin<Box<dyn Future<Output = Result<Vec<(Token, BoxedServerService)>, ()>>>> {
         self.as_ref().create()
     }
 }
 
-impl<F, T, I> StreamServiceFactory<I> for F
+impl<F, T> StreamServiceFactory for F
 where
-    F: Fn() -> T + Send + Clone + 'static,
-    T: ServiceFactory<Config = (), Request = I>,
-    I: FromStream,
+    F: Fn(Config) -> T + Send + Clone + 'static,
+    T: ServiceFactory<Io>,
 {
     type Factory = T;
 
     #[inline]
-    fn create(&self) -> T {
-        (self)()
+    fn create(&self, cfg: Config) -> T {
+        (self)(cfg)
     }
 }
