@@ -7,9 +7,9 @@ use serde_urlencoded::ser::Error as FormError;
 
 use crate::http::body::Body;
 use crate::http::helpers::Writer;
-use crate::http::ws::HandshakeError;
 use crate::http::{self, header, StatusCode};
 use crate::util::{timeout::TimeoutError, BytesMut};
+use crate::ws::error::HandshakeError;
 
 use super::error::{self, ErrorContainer, ErrorRenderer, WebResponseError};
 use super::{HttpRequest, HttpResponse};
@@ -83,9 +83,7 @@ impl fmt::Debug for Error {
 }
 
 /// Return `GATEWAY_TIMEOUT` for `TimeoutError`
-impl<E: WebResponseError<DefaultError>> WebResponseError<DefaultError>
-    for TimeoutError<E>
-{
+impl<E: WebResponseError<DefaultError>> WebResponseError<DefaultError> for TimeoutError<E> {
     fn status_code(&self) -> StatusCode {
         match self {
             TimeoutError::Service(e) => e.status_code(),
@@ -105,12 +103,12 @@ impl WebResponseError<DefaultError> for FormError {}
 
 #[cfg(feature = "openssl")]
 /// `InternalServerError` for `openssl::ssl::Error`
-impl WebResponseError<DefaultError> for crate::connect::openssl::SslError {}
+impl WebResponseError<DefaultError> for tls_openssl::ssl::Error {}
 
 #[cfg(feature = "openssl")]
 /// `InternalServerError` for `openssl::ssl::HandshakeError`
 impl<T: fmt::Debug + 'static> WebResponseError<DefaultError>
-    for open_ssl::ssl::HandshakeError<T>
+    for tls_openssl::ssl::HandshakeError<T>
 {
 }
 
